CREATE SCHEMA SIMULATION;

CREATE TABLE SIMULATION.AUX_CASE_MATCHING
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   MATCHED_CASE_INDEX INTEGER NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_MATCHING
  ADD CONSTRAINT C1394390 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX, MATCHED_CASE_INDEX);

CREATE TABLE SIMULATION.AUX_CASE_MDL_TASK_RES_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   TTL_TIMES_USED INTEGER NOT NULL,
   TTL_TIMES_CAUSED_DELAY INTEGER NOT NULL,
   TTL_ALLOCATIONS INTEGER NOT NULL,
   TTL_UNITS_USED DOUBLE NOT NULL,
   TTL_USAGE_DURATION BIGINT NOT NULL,
   TTL_USAGE_COST DOUBLE NOT NULL,
   TTL_SHORTAGE_DURATION BIGINT NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_MDL_TASK_RES_STATS
  ADD CONSTRAINT C2284965 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX, MDL_TASK_PRX_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.AUX_CASE_MDL_TASK_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   TTL_TASKS INTEGER NOT NULL,
   TTL_SUCCEEDED_TASKS INTEGER NOT NULL,
   TTL_TIMED_OUT_TASKS INTEGER NOT NULL,
   TTL_ELAPSED_DURATION BIGINT NOT NULL,
   TTL_WORKING_DURATION BIGINT NOT NULL,
   TTL_PROCESSING_DURATION BIGINT NOT NULL,
   TTL_RESOURCE_DURATION BIGINT NOT NULL,
   TTL_INIT_DELAY_DURATION BIGINT NOT NULL,
   TTL_INTERN_DELAY_DURATION BIGINT NOT NULL,
   TTL_STARTUP_COST DOUBLE NOT NULL,
   TTL_EXECUTION_COST DOUBLE NOT NULL,
   TTL_CREATION_COST DOUBLE NOT NULL,
   TTL_INIT_DELAY_COST DOUBLE NOT NULL,
   TTL_INTERN_DELAY_COST DOUBLE NOT NULL,
   TTL_RESOURCE_COST DOUBLE NOT NULL,
   TTL_REVENUE DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_MDL_TASK_STATS
  ADD CONSTRAINT C2284964 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX, MDL_TASK_PRX_ID);

CREATE TABLE SIMULATION.AUX_CASE_PATH
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   MDL_IN_OUT_PUT_CRITERIA_PRX_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_PATH
  ADD CONSTRAINT C5078580 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX, MDL_IN_OUT_PUT_CRITERIA_PRX_ID);

CREATE TABLE SIMULATION.AUX_CASE_PRX_TASK_RES_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   TTL_TIMES_USED INTEGER NOT NULL,
   TTL_TIMES_CAUSED_DELAY INTEGER NOT NULL,
   TTL_ALLOCATIONS INTEGER NOT NULL,
   TTL_UNITS_USED DOUBLE NOT NULL,
   TTL_USAGE_DURATION BIGINT NOT NULL,
   TTL_USAGE_COST DOUBLE NOT NULL,
   TTL_SHORTAGE_DURATION BIGINT NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_PRX_TASK_RES_STATS
  ADD CONSTRAINT C2284967 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX, PRX_TASK_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.AUX_CASE_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   SUCCEEDED SMALLINT NOT NULL,
   TTL_TOP_PROCESSES INTEGER NOT NULL,
   TTL_TASKS INTEGER NOT NULL,
   TTL_SUCCEEDED_TASKS INTEGER NOT NULL,
   TTL_TIMED_OUT_TASKS INTEGER NOT NULL,
   TTL_ELAPSED_DURATION BIGINT NOT NULL,
   TTL_WORKING_DURATION BIGINT NOT NULL,
   TTL_PROCESSING_DURATION BIGINT NOT NULL,
   TTL_RESOURCE_DURATION BIGINT NOT NULL,
   TTL_INIT_DELAY_DURATION BIGINT NOT NULL,
   TTL_INTERN_DELAY_DURATION BIGINT NOT NULL,
   TTL_STARTUP_COST DOUBLE NOT NULL,
   TTL_EXECUTION_COST DOUBLE NOT NULL,
   TTL_CREATION_COST DOUBLE NOT NULL,
   TTL_INIT_DELAY_COST DOUBLE NOT NULL,
   TTL_INTERN_DELAY_COST DOUBLE NOT NULL,
   TTL_RESOURCE_COST DOUBLE NOT NULL,
   TTL_REVENUE DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_STATS
  ADD CONSTRAINT C2958953 PRIMARY KEY (RTM_SIM_SESSION_ID, CASE_INDEX);

CREATE TABLE SIMULATION.AUX_CASE_TOP_PROCESS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   CASE_INDEX INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   TOP_PROCESS_INDEX INTEGER NOT NULL,
   COMPLETION_STATUS SMALLINT NOT NULL,
   TTL_TASKS INTEGER NOT NULL,
   TTL_SUCCEEDED_TASKS INTEGER NOT NULL,
   TTL_TIMED_OUT_TASKS INTEGER NOT NULL,
   INSTANTIATION_TIME BIGINT NOT NULL,
   TERMINATION_TIME BIGINT NOT NULL,
   WORKING_DURATION BIGINT NOT NULL,
   PROCESSING_DURATION BIGINT NOT NULL,
   RESOURCE_DURATION BIGINT NOT NULL,
   INIT_DELAY_DURATION BIGINT NOT NULL,
   INTERN_DELAY_DURATION BIGINT NOT NULL,
   STARTUP_COST DOUBLE NOT NULL,
   EXECUTION_COST DOUBLE NOT NULL,
   CREATION_COST DOUBLE NOT NULL,
   INIT_DELAY_COST DOUBLE NOT NULL,
   INTERN_DELAY_COST DOUBLE NOT NULL,
   RESOURCE_COST DOUBLE NOT NULL,
   REVENUE DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_CASE_TOP_PROCESS
  ADD CONSTRAINT C3320052 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_TASK_ID);

CREATE INDEX SIMULATION.AUX_CAS_TOP_PRO_X
  ON SIMULATION.AUX_CASE_TOP_PROCESS (RTM_SIM_SESSION_ID ASC, CASE_INDEX ASC, RTM_TASK_ID ASC);

CREATE TABLE SIMULATION.AUX_MDL_TASK_PROXY_ID
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.AUX_MDL_TASK_PROXY_ID
  ADD CONSTRAINT C8767194 PRIMARY KEY (RTM_SIM_SESSION_ID, PRX_TASK_ID, MDL_TASK_PRX_ID);

CREATE TABLE SIMULATION.AUX_MDL_TASK_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   TOP_PROCESS_SUCCEEDED SMALLINT NOT NULL,
   TTL_TASKS INTEGER NOT NULL,
   TTL_SUCCEEDED_TASKS INTEGER NOT NULL,
   TTL_TIMED_OUT_TASKS INTEGER NOT NULL,
   TTL_ELAPSED_DURATION BIGINT NOT NULL,
   TTL_WORKING_DURATION BIGINT NOT NULL,
   TTL_PROCESSING_DURATION BIGINT NOT NULL,
   TTL_RESOURCE_DURATION BIGINT NOT NULL,
   TTL_INIT_DELAY_DURATION BIGINT NOT NULL,
   TTL_INTERN_DELAY_DURATION BIGINT NOT NULL,
   TTL_STARTUP_COST DOUBLE NOT NULL,
   TTL_EXECUTION_COST DOUBLE NOT NULL,
   TTL_CREATION_COST DOUBLE NOT NULL,
   TTL_INIT_DELAY_COST DOUBLE NOT NULL,
   TTL_INTERN_DELAY_COST DOUBLE NOT NULL,
   TTL_RESOURCE_COST DOUBLE NOT NULL,
   TTL_REVENUE DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_MDL_TASK_STATS
  ADD CONSTRAINT C2601640 PRIMARY KEY (RTM_SIM_SESSION_ID, MDL_TASK_PRX_ID, TOP_PROCESS_SUCCEEDED);

CREATE TABLE SIMULATION.AUX_REQ_RESOURCE_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   SMS_RESOURCE_REQ_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   TTL_TIMES_USED INTEGER NOT NULL,
   TTL_TIMES_CAUSED_DELAY INTEGER NOT NULL,
   TTL_UNITS_USED DOUBLE NOT NULL,
   TTL_USAGE_DURATION BIGINT NOT NULL,
   TTL_USAGE_COST DOUBLE NOT NULL,
   TTL_SHORTAGE_DURATION BIGINT NOT NULL,
   TTL_ALLOCATIONS INTEGER NOT NULL);
   
ALTER TABLE SIMULATION.AUX_REQ_RESOURCE_STATS
  ADD CONSTRAINT C0117598 PRIMARY KEY (RTM_SIM_SESSION_ID, SMS_RESOURCE_REQ_PRX_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.AUX_RESOURCE_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   TTL_TIMES_USED INTEGER NOT NULL,
   TTL_TIMES_CAUSED_DELAY INTEGER NOT NULL,
   TTL_UNITS_USED DOUBLE NOT NULL,
   TTL_USAGE_DURATION BIGINT NOT NULL,
   TTL_USAGE_COST DOUBLE NOT NULL,
   TTL_SHORTAGE_DURATION BIGINT NOT NULL,
   TTL_ALLOCATIONS INTEGER NOT NULL,
   MAX_SIMULTANEOUS_USERS INTEGER NOT NULL,
   MAX_SIMULTANEOUS_USED_UNITS DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_RESOURCE_STATS
  ADD CONSTRAINT C0117587 PRIMARY KEY (RTM_SIM_SESSION_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.AUX_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   SUCCEEDED SMALLINT NOT NULL,
   TTL_TOP_PROCESSES INTEGER NOT NULL,
   TTL_TASKS INTEGER NOT NULL,
   TTL_SUCCEEDED_TASKS INTEGER NOT NULL,
   TTL_TIMED_OUT_TASKS INTEGER NOT NULL,
   TTL_ELAPSED_DURATION BIGINT NOT NULL,
   TTL_WORKING_DURATION BIGINT NOT NULL,
   TTL_PROCESSING_DURATION BIGINT NOT NULL,
   TTL_RESOURCE_DURATION BIGINT NOT NULL,
   TTL_INIT_DELAY_DURATION BIGINT NOT NULL,
   TTL_INTERN_DELAY_DURATION BIGINT NOT NULL,
   TTL_STARTUP_COST DOUBLE NOT NULL,
   TTL_EXECUTION_COST DOUBLE NOT NULL,
   TTL_CREATION_COST DOUBLE NOT NULL,
   TTL_INIT_DELAY_COST DOUBLE NOT NULL,
   TTL_INTERN_DELAY_COST DOUBLE NOT NULL,
   TTL_RESOURCE_COST DOUBLE NOT NULL,
   TTL_REVENUE DOUBLE NOT NULL);

ALTER TABLE SIMULATION.AUX_STATS
  ADD CONSTRAINT C2185874 PRIMARY KEY (RTM_SIM_SESSION_ID, SUCCEEDED);

CREATE TABLE SIMULATION.EVT_INPUT_CRIT_ACTIVATION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   EVT_INPUT_CRIT_ACTIVATION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   PRX_INPUT_CRITERIA_ID INTEGER NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_INPUT_CRIT_ACTIVATION
  ADD CONSTRAINT C2234608 PRIMARY KEY (RTM_SIM_SESSION_ID, EVT_INPUT_CRIT_ACTIVATION_ID);
  
CREATE INDEX SIMULATION.EVT_INP_CRI_ACT_X
  ON SIMULATION.EVT_INPUT_CRIT_ACTIVATION (RTM_SIM_SESSION_ID ASC, RTM_TASK_ID ASC);

CREATE TABLE SIMULATION.EVT_OUTPUT_CRIT_ACTIVATION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   EVT_OUTPUT_CRIT_ACTIVATION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   PRX_OUTPUT_CRITERIA_ID INTEGER NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_OUTPUT_CRIT_ACTIVATION
  ADD CONSTRAINT C0257094 PRIMARY KEY (RTM_SIM_SESSION_ID, EVT_OUTPUT_CRIT_ACTIVATION_ID);
  
CREATE INDEX SIMULATION.EVT_OUT_CRI_ACT_X
  ON SIMULATION.EVT_OUTPUT_CRIT_ACTIVATION (RTM_SIM_SESSION_ID ASC, RTM_TASK_ID ASC);

CREATE TABLE SIMULATION.EVT_SIM_SESSION_END
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_SIM_SESSION_END
  ADD CONSTRAINT C4001381 PRIMARY KEY (RTM_SIM_SESSION_ID);

CREATE TABLE SIMULATION.EVT_SIM_SESSION_START
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_SIM_SESSION_START
  ADD CONSTRAINT C7785551 PRIMARY KEY (RTM_SIM_SESSION_ID);

CREATE TABLE SIMULATION.EVT_TASK_INSTANTIATION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   RTM_PROCESS_ID INTEGER NOT NULL,
   RTM_TOP_PROCESS_ID INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_TASK_INSTANTIATION
  ADD CONSTRAINT C3409043 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_TASK_ID);

CREATE INDEX SIMULATION.EVT_TAS_INS_X
  ON SIMULATION.EVT_TASK_INSTANTIATION (RTM_SIM_SESSION_ID ASC, RTM_TOP_PROCESS_ID ASC);

CREATE TABLE SIMULATION.EVT_TASK_TERMINATION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   COMPLETION_STATUS SMALLINT NOT NULL,
   WORKING_DURATION BIGINT NOT NULL,
   PROCESSING_DURATION BIGINT NOT NULL,
   RESOURCE_DURATION BIGINT NOT NULL,
   INIT_DELAY_DURATION BIGINT NOT NULL,
   INTERN_DELAY_DURATION BIGINT NOT NULL,
   STARTUP_COST DOUBLE NOT NULL,
   EXECUTION_COST DOUBLE NOT NULL,
   CREATION_COST DOUBLE NOT NULL,
   INIT_DELAY_COST DOUBLE NOT NULL,
   INTERN_DELAY_COST DOUBLE NOT NULL,
   RESOURCE_COST DOUBLE NOT NULL,
   REVENUE DOUBLE NOT NULL,
   REAL_TIME BIGINT,
   VIRTUAL_TIME BIGINT NOT NULL);

ALTER TABLE SIMULATION.EVT_TASK_TERMINATION
  ADD CONSTRAINT C4253753 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_TASK_ID, COMPLETION_STATUS);

CREATE TABLE SIMULATION.MDL_CLASSIFIER
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_ID CHARACTER(36) NOT NULL,
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_CLASSIFIER
  ADD CONSTRAINT C7251846 PRIMARY KEY (MDL_PRX_ID, MDL_CLASSIFIER_PRX_ID);

CREATE TABLE SIMULATION.MDL_CLASSIFIER_VALUE
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_VALUE_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_VALUE_ID CHARACTER(36) NOT NULL,
   VALUE VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_CLASSIFIER_VALUE
  ADD CONSTRAINT C1297812 PRIMARY KEY (MDL_PRX_ID, MDL_CLASSIFIER_VALUE_PRX_ID);

CREATE TABLE SIMULATION.MDL_INPUT_CRITERIA
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_INPUT_CRITERIA_PRX_ID INTEGER NOT NULL,
   MDL_INPUT_CRITERIA_ID CHARACTER(36) NOT NULL,
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_INPUT_CRITERIA
  ADD CONSTRAINT C0154658 PRIMARY KEY (MDL_PRX_ID, MDL_INPUT_CRITERIA_PRX_ID);

CREATE TABLE SIMULATION.MDL_OUTPUT_CRITERIA
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_OUTPUT_CRITERIA_PRX_ID INTEGER NOT NULL,
   MDL_OUTPUT_CRITERIA_ID CHARACTER(36) NOT NULL,
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_OUTPUT_CRITERIA
  ADD CONSTRAINT C0438950 PRIMARY KEY (MDL_PRX_ID, MDL_OUTPUT_CRITERIA_PRX_ID);

CREATE TABLE SIMULATION.MDL_RESOURCE
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_ID CHARACTER(36) NOT NULL,
   RESOURCE_TCODE SMALLINT NOT NULL,
   CONSUMABLE SMALLINT NOT NULL,
   NNRM_UNITS_AVAILABLE DOUBLE NOT NULL,
   UNITS_AVAILABLE DOUBLE NOT NULL,
   NNRM_UNIT_MEASURE VARCHAR(32) NOT NULL,
   UNIT_MEASURE VARCHAR(32) NOT NULL, 
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_RESOURCE
  ADD CONSTRAINT C9214894 PRIMARY KEY (MDL_PRX_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.MDL_ROLE
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_ROLE_PRX_ID INTEGER NOT NULL,
   MDL_ROLE_ID CHARACTER(36) NOT NULL,
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.MDL_ROLE
  ADD CONSTRAINT C3594105 PRIMARY KEY (MDL_PRX_ID, MDL_ROLE_PRX_ID);

CREATE TABLE SIMULATION.MDL_TASK
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   MDL_TASK_ID CHARACTER(36) NOT NULL, 
   MDL_PROCESS_PRX_ID INTEGER NOT NULL,
   MDL_TASK_TCODE SMALLINT NOT NULL,
   SMS_TASK_TCODE SMALLINT NOT NULL,
   NAME VARCHAR(55) NOT NULL,
   NAME_PATH VARCHAR(512) NOT NULL);

ALTER TABLE SIMULATION.MDL_TASK
  ADD CONSTRAINT C6286037 PRIMARY KEY (MDL_TASK_PRX_ID, MDL_PRX_ID);

CREATE TABLE SIMULATION.MDL_TASK_BEHAVIOR
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   MDL_BEHAVIOR_PRX_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.MDL_TASK_BEHAVIOR
  ADD CONSTRAINT C7044401 PRIMARY KEY (MDL_PRX_ID, MDL_TASK_PRX_ID);

CREATE TABLE SIMULATION.MDL_TASK_CLASSIFICATION
  (MDL_PRX_ID INTEGER NOT NULL,
   MDL_CLASSIFIER_VALUE_PRX_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.MDL_TASK_CLASSIFICATION
  ADD CONSTRAINT C3456084 PRIMARY KEY (MDL_PRX_ID, MDL_CLASSIFIER_VALUE_PRX_ID, MDL_TASK_PRX_ID);

CREATE TABLE SIMULATION.PRX_INPUT_CRITERIA
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   PRX_INPUT_CRITERIA_ID INTEGER NOT NULL,
   MDL_INPUT_CRITERIA_PRX_ID INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.PRX_INPUT_CRITERIA
  ADD CONSTRAINT C7702925 PRIMARY KEY (RTM_SIM_SESSION_ID, PRX_INPUT_CRITERIA_ID);

CREATE TABLE SIMULATION.PRX_OUTPUT_CRITERIA
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   PRX_OUTPUT_CRITERIA_ID INTEGER NOT NULL,
   MDL_OUTPUT_CRITERIA_PRX_ID INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.PRX_OUTPUT_CRITERIA
  ADD CONSTRAINT C7855371 PRIMARY KEY (RTM_SIM_SESSION_ID, PRX_OUTPUT_CRITERIA_ID);

CREATE TABLE SIMULATION.PRX_TASK
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   PRX_TASK_ID INTEGER NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   PRX_PROCESS_ID INTEGER NOT NULL, 
   LAYER SMALLINT NOT NULL,
   PRX_NAME_PATH VARCHAR(512) NOT NULL);

ALTER TABLE SIMULATION.PRX_TASK
  ADD CONSTRAINT C8006412 PRIMARY KEY (RTM_SIM_SESSION_ID, PRX_TASK_ID);

CREATE TABLE SIMULATION.RTM_RESOURCE_ALLOCATION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   RTM_RESOURCE_USAGE_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   SMS_RESOURCE_REQ_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   FROM_TIME BIGINT NOT NULL,
   TO_TIME BIGINT NOT NULL,
   UNITS_USED DOUBLE NOT NULL,
   USAGE_COST DOUBLE NOT NULL,
   SHORTAGE_DURATION BIGINT NOT NULL);

ALTER TABLE SIMULATION.RTM_RESOURCE_ALLOCATION
  ADD CONSTRAINT C1442633 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_RESOURCE_USAGE_ID, RTM_TASK_ID, FROM_TIME, TO_TIME);

CREATE INDEX SIMULATION.RTM_RES_ALL_X
  ON SIMULATION.RTM_RESOURCE_ALLOCATION (RTM_SIM_SESSION_ID ASC, RTM_TASK_ID, RTM_RESOURCE_USAGE_ID ASC);

CREATE TABLE SIMULATION.RTM_RESOURCE_USAGE
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   SMS_RESOURCE_REQ_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   RTM_RESOURCE_USAGE_ID INTEGER NOT NULL,
   UNITS_USED DOUBLE NOT NULL,
   USAGE_DURATION BIGINT NOT NULL,
   USAGE_COST DOUBLE NOT NULL,
   SHORTAGE_DURATION BIGINT NOT NULL,
   ALLOCATIONS INTEGER NOT NULL,
   FROM_TIME BIGINT NOT NULL,
   TO_TIME BIGINT NOT NULL,
   SIMULTANEOUS_USERS BIGINT NOT NULL,
   SIMULTANEOUS_USED_UNITS DOUBLE NOT NULL);

ALTER TABLE SIMULATION.RTM_RESOURCE_USAGE
  ADD CONSTRAINT C7468718 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_TASK_ID, SMS_RESOURCE_REQ_PRX_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.RTM_RESOURCE_STATS
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   MDL_RESOURCE_PRX_ID INTEGER NOT NULL,
   AVAILABILITY_DURATION BIGINT NOT NULL,
   NON_IDLE_DURATION BIGINT NOT NULL);

ALTER TABLE SIMULATION.RTM_RESOURCE_STATS
  ADD CONSTRAINT C9214895 PRIMARY KEY (RTM_SIM_SESSION_ID, MDL_RESOURCE_PRX_ID);

CREATE TABLE SIMULATION.SMS_RESOURCE_REQ
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   SMS_RESOURCE_REQ_PRX_ID INTEGER NOT NULL,
   MDL_RESOURCE_REQ_ID CHARACTER(36) NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL,
   MDL_REQ_RESOURCE_PRX_ID INTEGER NOT NULL,
   RESOURCE_REQ_TCODE SMALLINT NOT NULL,
   NNRM_UNITS_REQUIRED DOUBLE NOT NULL, 
   UNITS_REQUIRED DOUBLE NOT NULL, 
   NNRM_UNIT_MEASURE VARCHAR(32) NOT NULL,
   UNIT_MEASURE VARCHAR(32) NOT NULL, 
   NAME VARCHAR(55) NOT NULL);

ALTER TABLE SIMULATION.SMS_RESOURCE_REQ
  ADD CONSTRAINT C0117588 PRIMARY KEY (RTM_SIM_SESSION_ID, SMS_RESOURCE_REQ_PRX_ID, MDL_TASK_PRX_ID);

CREATE TABLE SIMULATION.SMS_SIM_SESSION
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   SIM_SESSION_ID CHARACTER(36) NOT NULL,
   MDL_PRX_ID INTEGER NOT NULL,
   SPECIFIED_SEED BIGINT NOT NULL,
   ACTUAL_SEED BIGINT NOT NULL,
   SIMULATION_MODE SMALLINT NOT NULL,
   CURRENCY_SYMBOL CHARACTER(3) NOT NULL);

ALTER TABLE SIMULATION.SMS_SIM_SESSION
  ADD CONSTRAINT C7258664 PRIMARY KEY (RTM_SIM_SESSION_ID);

CREATE TABLE SIMULATION.SYS_AUX_KEY_VALUE
  (KEY_NAME CHARACTER(30) NOT NULL,
   KEY_VALUE INTEGER NOT NULL);

ALTER TABLE SIMULATION.SYS_AUX_KEY_VALUE
  ADD CONSTRAINT C9672179 PRIMARY KEY (KEY_NAME);

CREATE TABLE SIMULATION.TRG_RESOURCE_USAGE_L2
  (RTM_SIM_SESSION_ID INTEGER NOT NULL,
   RTM_TASK_ID INTEGER NOT NULL,
   TOP_PROCESS_INDEX INTEGER NOT NULL,
   TASK_INSTANTIATION_TIME BIGINT NOT NULL,
   MDL_TASK_PRX_ID INTEGER NOT NULL);

ALTER TABLE SIMULATION.TRG_RESOURCE_USAGE_L2
  ADD CONSTRAINT C5440127 PRIMARY KEY (RTM_SIM_SESSION_ID, RTM_TASK_ID);


INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('RTM_SIM_SESSION_ID', 0);
INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('VERSION_MAJOR', 6);
INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('VERSION_MINOR', 1);
INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('VERSION_SUB_MINOR', 1);
INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('VERSION_SUB_SUB_MINOR', 0);
INSERT INTO SIMULATION.SYS_AUX_KEY_VALUE (KEY_NAME, KEY_VALUE)
   VALUES ('VERSION_PATCH', 0);